# -*- coding: utf-8 -*-

addAnnouncement = 'contenttypes.basic: Add Announcement'
addBanner = 'contenttypes.basic: Add Banner'
addIcon = 'contenttypes.basic: Add Icon'
addSlide = 'contenttypes.basic: Add Slide'

manageCoordinatesControlPanel = 'contenttypes.basic: Manage Coordinates ControlPanel'
